@@ -1,21 +1,20 @@
 # The COPYRIGHT file at the top level of this repository contains
 # the full copyright notices and license terms.
 import unittest
-
 from decimal import Decimal
+
 from dateutil.relativedelta import relativedelta
-
-from trytond.tests.test_tryton import ModuleTestCase, with_transaction
-from trytond.tests.test_tryton import suite as test_suite
-from trytond.transaction import Transaction
-from trytond.pool import Pool
 from trytond.exceptions import UserError
-
 from trytond.modules.account.tests import create_chart, get_fiscalyear
-from trytond.modules.company.tests import create_company, set_company
 from trytond.modules.account_invoice.tests import set_invoice_sequences
-from trytond.modules.payment_gateway.tests import (create_payment_transaction,
-    create_payment_profile)
+from trytond.modules.company.tests import create_company, set_company
+from trytond.modules.payment_gateway.tests import (
+    create_payment_profile, create_payment_transaction)
+from trytond.pool import Pool
+from trytond.tests.test_tryton import ModuleTestCase
+from trytond.tests.test_tryton import suite as test_suite
+from trytond.tests.test_tryton import with_transaction
+from trytond.transaction import Transaction
 
 
 def create_write_off():
